.. streamlit-jdgrid documentation master file, created by
   sphinx-quickstart on Wed Feb  7 17:00:57 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to streamlit-jdgrid's documentation!
============================================

:Version: |version|

.. toctree::
   :maxdepth: 2
   :caption: Contents:

.. toctree::
   :maxdepth: 1
   :caption: API:

   AgGrid
   GridOptionsBuilder


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
